@@ -14,6 +14,14 @@ class BaseFlasher(ABC):
         """
         pass
     
+    @classmethod
+    def name():
+        """Get the name of the programmer.
+
+        This method should be overridden by the subclass.
+        """
+        pass
+    
 
     @classmethod
     @abstractmethod
@@ -31,3 +39,11 @@ class BaseFlasher(ABC):
         This method should be overridden by the subclass.
         """
         pass
+    
+    @abstractmethod
+    def write_sn(self):
+        """Write serial number to the programmer.
+
+        This method should be overridden by the subclass.
+        """
+        pass
